@@ -16,7 +16,7 @@
 #
 '''Handles different storage files.'''
 
-__version__ = "$Id: db.py 273 2006-12-30 15:54:50Z wrobel $"
+__version__ = "$Id: db.py 286 2007-01-09 17:48:23Z wrobel $"
 
 #===============================================================================
 #
@@ -72,7 +72,8 @@ class DB(Overlays):
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : write2,
         ...           'nocheck'    : True,
-        ...           'storage'   : write3}
+        ...           'storage'   : write3,
+        ...           'quietness':3}
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> a = DB(config)
@@ -107,6 +108,8 @@ class DB(Overlays):
         if overlay.name not in self.overlays.keys():
             result = overlay.add(self.config['storage'])
             if result == 0:
+                if 'priority' in self.config.keys():
+                    overlay.priority = int(self.config['priority'])
                 self.overlays[overlay.name] = overlay
                 self.write(self.path)
                 make_conf = MakeConf(self.config, self.overlays)
@@ -130,7 +133,8 @@ class DB(Overlays):
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : write2,
         ...           'nocheck'    : True,
-        ...           'storage'   : write3}
+        ...           'storage'   : write3,
+        ...           'quietness':3}
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
         >>> a = DB(config)
@@ -232,7 +236,8 @@ class RemoteDB(Overlays):
         ...           'file://' + here + '/tests/testfiles/global-overlays.xml',
         ...           'cache' : cache,
         ...           'nocheck'    : True,
-        ...           'proxy' : None}
+        ...           'proxy' : None,
+        ...           'quietness':3}
         >>> a = RemoteDB(config)
         >>> a.cache()
         >>> b = open(a.path(config['overlays']))
@@ -327,7 +332,8 @@ class MakeConf:
     ...           here + '/tests/testfiles/global-overlays.xml',
     ...           'make_conf' : here + '/tests/testfiles/make.conf',
     ...           'nocheck'    : True,
-    ...           'storage'   : '/usr/portage/local/layman'}
+    ...           'storage'   : '/usr/portage/local/layman',
+    ...           'quietness':3}
     >>> b = DB(config)
     >>> a = MakeConf(config, b.overlays)
     >>> o_md5 = str(md5.md5(open(here + '/tests/testfiles/make.conf').read()).hexdigest())
@@ -374,7 +380,8 @@ class MakeConf:
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : here + '/tests/testfiles/make.conf',
         ...           'nocheck'    : True,
-        ...           'storage'   : '/usr/portage/local/layman'}
+        ...           'storage'   : '/usr/portage/local/layman',
+        ...           'quietness':3}
         >>> c = DB(config)
         >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
@@ -401,7 +408,8 @@ class MakeConf:
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : here + '/tests/testfiles/make.conf',
         ...           'nocheck'    : True,
-        ...           'storage'   : '/usr/portage/local/layman'}
+        ...           'storage'   : '/usr/portage/local/layman',
+        ...           'quietness':3}
         >>> c = DB(config)
         >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
@@ -429,7 +437,8 @@ class MakeConf:
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : here + '/tests/testfiles/make.conf',
         ...           'nocheck'    : True,
-        ...           'storage'   : '/usr/portage/local/layman'}
+        ...           'storage'   : '/usr/portage/local/layman',
+        ...           'quietness':3}
         >>> c = DB(config)
         >>> a = MakeConf(config, c.overlays)
         >>> [i.name for i in a.overlays]
@@ -483,7 +492,8 @@ class MakeConf:
         ...           here + '/tests/testfiles/global-overlays.xml',
         ...           'make_conf' : here + '/tests/testfiles/make.conf',
         ...           'nocheck'    : True,
-        ...           'storage'   : '/usr/portage/local/layman'}
+        ...           'storage'   : '/usr/portage/local/layman',
+        ...           'quietness':3}
         >>> c = DB(config)
         >>> a = MakeConf(config, c.overlays)
         >>> a.path = write
@@ -511,8 +521,9 @@ class MakeConf:
         for i in self.overlays:
             paths.append(path((self.storage, i.name, )))
 
-        overlays = 'PORTDIR_OVERLAY="$PORTDIR_OVERLAY\n'
+        overlays = 'PORTDIR_OVERLAY="\n'
         overlays += '\n'.join(paths) + '\n'
+        overlays += '$PORTDIR_OVERLAY\n'
         overlays += '\n'.join(self.extra)
         overlays += '"'
 
