@@ -16,7 +16,7 @@
 #
 '''Main handler for overlays.'''
 
-__version__ = "$Id: overlay.py 252 2006-09-23 07:31:40Z wrobel $"
+__version__ = "$Id: overlay.py 273 2006-12-30 15:54:50Z wrobel $"
 
 #===============================================================================
 #
@@ -61,8 +61,9 @@ OVERLAY_TYPES = {'git'       : GitOverlay,
 class Overlays:
     ''' Handle a list of overlays.'''
 
-    def __init__(self, paths, ignore = 0):
+    def __init__(self, paths, ignore = 0, quiet = False):
 
+        self.quiet = quiet
         self.paths = paths
         self.ignore = ignore
 
@@ -121,10 +122,11 @@ class Overlays:
                     if attr.nodeValue in OVERLAY_TYPES.keys():
                         try:
                             ovl = OVERLAY_TYPES[attr.nodeValue](overlay,
-                                                               self.ignore)
+                                                                self.ignore,
+                                                                self.quiet)
                             self.overlays[ovl.name] = ovl
                         except Exception, error:
-                            OUT.warn(str(error))
+                            OUT.warn(str(error), 3)
                     else:
                         raise Exception('Unknown overlay type "' +
                                         attr.nodeValue + '"!')
